Fix various typos, scattered over the code.
Spelling corrections for (among other things):
* environment
* override
* variable
* ftd (should be "fdt", for flattened device tree)
* embedded
* FTDI
* emulation
* controller
diff --git a/tools/moveconfig.py b/tools/moveconfig.py
index 6f71b55..68631b7 100755
--- a/tools/moveconfig.py
+++ b/tools/moveconfig.py
@@ -273,12 +273,12 @@
color_text(color_enabled, color, msg) + '\n'
def update_cross_compile():
"""Update per-arch CROSS_COMPILE via enviroment variables
The default CROSS_COMPILE values are available
in the CROSS_COMPILE list above.
- You can override them via enviroment variables
+ You can override them via environment variables
CROSS_COMPILE_{ARCH}.
For example, if you want to override toolchain prefixes
@@ -273,12 +273,12 @@
color_text(color_enabled, color, msg) + '\n'
def update_cross_compile():
- """Update per-arch CROSS_COMPILE via enviroment variables
+ """Update per-arch CROSS_COMPILE via environment variables
The default CROSS_COMPILE values are available
in the CROSS_COMPILE list above.